powered by
This function lists all the conflicts between packages in the bupaverse and other packages that you have loaded.
bupaverse
bupaverse_conflicts()
Returns a list all the conflicts between packages in the bupaverse and other packages that you have loaded.
list
Run the code above in your browser using DataLab